==> homerun-0.2.0.tar.bz2: homerun-0.2.0/applet/plasma-applet-homerunlauncher.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=KDE Homerun Launcher
Name[da]=KDE Homerun-startmenu
Name[el]=Εκτελεστής KDE Homerun
Name[es]=Lanzador Homerun de KDE
Name[et]=KDE Homeruni käivitaja
Name[fi]=KDE Homerun -käynnistin
Name[fr]=Lanceur Homerun pour KDE
Name[gl]=Lanzador de KDE Homerun
Name[hu]=KDE Homerun indító
Name[lt]=KDE Homerun leidiklis
Name[nl]=Programmastarter van KDE Homerun
Name[pa]=ਕੇਡੀਈ ਹੋਮਰਨ ਲਾਂਚਰ
Name[pt]=Lançador Homerun do KDE
Name[pt_BR]=Lançador Homerun do KDE
Name[ro]=Lansator KDE Homerun
Name[sk]=Spúšťač KDE Homerun
Name[sv]=KDE Homerun startprogram
Name[uk]=Засіб запуску KDE Homerun
Name[x-test]=xxKDE Homerun Launcherxx
Name[zh_CN]=KDE Homerun 启动器

Comment=An application launcher
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de aplicativos
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[sk]=Spúšťač aplikácií
Comment[sv]=Ett startprogram
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Type=Service
ServiceTypes=Plasma/Applet
Icon=homerun

X-KDE-Library=plasma_applet_homerunlauncher
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=homerunlauncher
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-Requires-FileDialog=Unused
X-Plasma-Requires-LaunchApp=Unused

==> homerun-0.2.3.tar.bz2: homerun-0.2.3/applet/plasma-applet-homerunlauncher.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
# ctxt: "Homerun" is a product name
Name=KDE Homerun Launcher
Name[cs]=Spouštěč KDE Homerun
Name[da]=KDE Homerun-startmenu
Name[de]=KDE Homerun-Starter
Name[el]=Εκτελεστής KDE Homerun
Name[es]=Lanzador Homerun de KDE
Name[et]=KDE Homeruni käivitaja
Name[fi]=KDE Homerun -käynnistin
Name[fr]=Lanceur Homerun pour KDE
Name[gl]=Lanzador de KDE Homerun
Name[hu]=KDE Homerun indító
Name[lt]=KDE Homerun leidiklis
Name[mr]=केडीई होमरन प्रक्षेपक
Name[nl]=Programmastarter van KDE Homerun
Name[pa]=ਕੇਡੀਈ ਹੋਮਰਨ ਲਾਂਚਰ
Name[pt]=Lançador Homerun do KDE
Name[pt_BR]=Lançador Homerun do KDE
Name[ro]=Lansator KDE Homerun
Name[ru]=Запуск KDE Homerun
Name[sk]=Spúšťač KDE Homerun
Name[sl]=Zaganjalnik Homerun za KDE
Name[sv]=KDE Homerun startprogram
Name[tr]=KDE Homerun Çalıştırıcı
Name[uk]=Засіб запуску KDE Homerun
Name[x-test]=xxKDE Homerun Launcherxx
Name[zh_CN]=KDE Homerun 启动器

Comment=An application launcher
Comment[cs]=Spouštěč aplikací
Comment[da]=Programstarter
Comment[de]=Ein Anwendungsstarter
Comment[el]=Ένας εκτελεστής εφαρμογών
Comment[es]=Un lanzador de aplicaciones
Comment[et]=Rakenduste käivitaja
Comment[fi]=Sovelluskäynnistin
Comment[fr]=Un lanceur d'applications
Comment[gl]=Un lanzador de aplicativos
Comment[hu]=Egy alkalmazásindító
Comment[lt]=Programų leidiklis
Comment[mr]=अनुप्रयोग प्रक्षेपक
Comment[nl]=Een programmastarter
Comment[pa]=ਐਪਲੀਕੇਸ਼ਨ ਲਾਂਚਰ
Comment[pt]=Um lançador de aplicações
Comment[pt_BR]=Um lançador de aplicativos
Comment[ro]=Lansator de aplicații
Comment[ru]=Запуск приложения
Comment[sk]=Spúšťač aplikácií
Comment[sl]=Zaganjalnik programov
Comment[sv]=Ett startprogram
Comment[tr]=Bir uygulama çalıştırıcı
Comment[uk]=Засіб для запуску програм
Comment[x-test]=xxAn application launcherxx
Comment[zh_CN]=一个应用程序启动器

Type=Service
ServiceTypes=Plasma/Applet
Icon=homerun

X-KDE-Library=plasma_applet_homerunlauncher
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=homerunlauncher
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-Requires-FileDialog=Unused
X-Plasma-Requires-LaunchApp=Unused
